@@ -112,7 +112,7 @@ using_direct::valid_line (unsigned int boundary) const
   try
     {
       CORE_ADDR curr_pc = get_frame_pc (get_selected_frame (nullptr));
-      symtab_and_line curr_sal = find_pc_line (curr_pc, 0);
+      symtab_and_line curr_sal = find_sal_for_pc (curr_pc, 0);
       return (decl_line <= curr_sal.line)
 	     || (decl_line >= boundary);
     }
